service: Fix typo SERIVCE_E_NOT_ENOUGH_DATA to SERVICE_E_NOT_ENOUGH_DATA
diff --git a/src/property_list_service.c b/src/property_list_service.c
index a6e3e24..1cb8dc9 100644
--- a/src/property_list_service.c
+++ b/src/property_list_service.c
@@ -48,7 +48,7 @@
 			return PROPERTY_LIST_SERVICE_E_MUX_ERROR;
 		case SERVICE_E_SSL_ERROR:
 			return PROPERTY_LIST_SERVICE_E_SSL_ERROR;
-		case SERIVCE_E_NOT_ENOUGH_DATA:
+		case SERVICE_E_NOT_ENOUGH_DATA:
 			return PROPERTY_LIST_SERVICE_E_NOT_ENOUGH_DATA;
 		case SERVICE_E_TIMEOUT:
 			return PROPERTY_LIST_SERVICE_E_RECEIVE_TIMEOUT;
diff --git a/src/service.c b/src/service.c
index 57d987c..661c4f6 100644
--- a/src/service.c
+++ b/src/service.c
@@ -47,7 +47,7 @@
 		case IDEVICE_E_SSL_ERROR:
 			return SERVICE_E_SSL_ERROR;
 		case IDEVICE_E_NOT_ENOUGH_DATA:
-			return SERIVCE_E_NOT_ENOUGH_DATA;
+			return SERVICE_E_NOT_ENOUGH_DATA;
 		case IDEVICE_E_TIMEOUT:
 			return SERVICE_E_TIMEOUT;
 		default:
diff --git a/include/libimobiledevice/service.h b/include/libimobiledevice/service.h
index 5c43e29..facf03b 100644
--- a/include/libimobiledevice/service.h
+++ b/include/libimobiledevice/service.h
@@ -37,7 +37,7 @@
 	SERVICE_E_MUX_ERROR           = -3,
 	SERVICE_E_SSL_ERROR           = -4,
 	SERVICE_E_START_SERVICE_ERROR = -5,
-	SERIVCE_E_NOT_ENOUGH_DATA     = -6,
+	SERVICE_E_NOT_ENOUGH_DATA     = -6,
 	SERVICE_E_TIMEOUT             = -7,
 	SERVICE_E_UNKNOWN_ERROR       = -256
 } service_error_t;
@@ -134,7 +134,7 @@
  *
  * @return SERVICE_E_SUCCESS on success,
  *      SERVICE_E_INVALID_ARG when one or more parameters are
  *      invalid, SERIVCE_E_NOT_ENOUGH_DATA when not enough data
  *      received, SERVICE_E_TIMEOUT when the connection times out,
  *      SERVICE_E_MUX_ERROR when a communication error
  *      occurs, or SERVICE_E_UNKNOWN_ERROR when an unspecified
@@ -150,7 +150,7 @@
  *
  * @return SERVICE_E_SUCCESS on success,
  *     SERVICE_E_INVALID_ARG if client or client->connection is
  *     NULL, SERIVCE_E_NOT_ENOUGH_DATA when not enough data
  *     received, SERVICE_E_TIMEOUT when the connection times out,
  *     SERVICE_E_SSL_ERROR when SSL could not be enabled,
  *     or SERVICE_E_UNKNOWN_ERROR otherwise.
@@ -134,7 +134,7 @@
  * @return SERVICE_E_SUCCESS on success,
  *      SERVICE_E_INVALID_ARG when one or more parameters are
- *      invalid, SERIVCE_E_NOT_ENOUGH_DATA when not enough data
+ *      invalid, SERVICE_E_NOT_ENOUGH_DATA when not enough data
  *      received, SERVICE_E_TIMEOUT when the connection times out,
  *      SERVICE_E_MUX_ERROR when a communication error
@@ -150,7 +150,7 @@
  * @return SERVICE_E_SUCCESS on success,
  *     SERVICE_E_INVALID_ARG if client or client->connection is
- *     NULL, SERIVCE_E_NOT_ENOUGH_DATA when not enough data
+ *     NULL, SERVICE_E_NOT_ENOUGH_DATA when not enough data
  *     received, SERVICE_E_TIMEOUT when the connection times out,
  *     SERVICE_E_SSL_ERROR when SSL could not be enabled,